@@ -27,7 +27,7 @@ string readfile (const std::string_view& path) {
     rewind(fh);
     string ret(size);
     size_t readsize = fread(ret.buf(), sizeof(char), size, fh);
-    if (readsize != size) return string();
+    if (readsize != (size_t)size) return string();
     
     fclose(fh);
     ret.length(readsize);
